/// <reference types="node" />
import { Socket } from 'socket.io-client';
import { InitializationOptions, ConnectionUpdateFunction, MessageCallback, SubscriptionErrorCallback, GrantErrorCallback, TelemetryCallback } from './types';
import { CachedValueType, DesiredPropertyGrantRequest, DirectMethodGrantRequest, GrantRequest, IoTHubResponse, LastValueConnectionStateResponse, LastValueDeviceTwinResponse, LastValueObj, LastValueResponse, LastValueTelemetryResponse, SubscriptionRequest, TelemetrySubscriptionRequest } from './ux4iot-shared';
import { Ux4iotApi } from './Ux4iotApi';
import { DeviceMethodParams } from 'azure-iothub';
export declare class Ux4iot {
    sessionId: string;
    socket: Socket | undefined;
    devMode: boolean;
    api: Ux4iotApi;
    retryTimeoutAfterError?: NodeJS.Timeout;
    onSocketConnectionUpdate?: ConnectionUpdateFunction;
    onSessionId?: (sessionId: string) => void;
    private constructor();
    static create(options: InitializationOptions, onSessionId?: (sessionId: string) => void): Promise<Ux4iot>;
    private initializeSocket;
    private tryReconnect;
    private onConnect;
    private onConnectError;
    private onDisconnect;
    destroy(): Promise<void>;
    private onData;
    patchDesiredProperties(grantRequest: DesiredPropertyGrantRequest, patch: Record<string, unknown>, onGrantError?: GrantErrorCallback): Promise<IoTHubResponse | void>;
    invokeDirectMethod(grantRequest: DirectMethodGrantRequest, options: DeviceMethodParams, onGrantError?: GrantErrorCallback): Promise<IoTHubResponse | void>;
    grant(grantRequest: GrantRequest, onGrantError?: GrantErrorCallback): Promise<void>;
    subscribe(subscriberId: string, subscriptionRequest: SubscriptionRequest, onData: MessageCallback, onSubscriptionError?: SubscriptionErrorCallback, onGrantError?: GrantErrorCallback): Promise<void>;
    unsubscribe(subscriberId: string, subscriptionRequest: SubscriptionRequest, onSubscriptionError?: SubscriptionErrorCallback, onGrantError?: GrantErrorCallback): Promise<void>;
    subscribeAllTelemetry(sessionId: string, deviceId: string, telemetryKeys: string[], subscriberId: string, onData: TelemetryCallback, onSubscriptionError?: SubscriptionErrorCallback, onGrantError?: GrantErrorCallback): Promise<void>;
    unsubscribeAllTelemetry(sessionId: string, deviceId: string, telemetryKeys: string[], subscriberId: string, onSubscriptionError?: SubscriptionErrorCallback, onGrantError?: GrantErrorCallback): Promise<void>;
    hasSubscription(subscriberId: string, subscriptionRequest: SubscriptionRequest): boolean;
    getSubscriberIdSubscriptions(subscriberId: string): Record<string, string[]>;
    removeSubscriberId(subscriberId: string, sessionId: string): Promise<void>;
    getLastTelemetryValues(deviceId: string, subscriptionRequest: TelemetrySubscriptionRequest[]): Promise<LastValueResponse<Record<string, LastValueObj<CachedValueType>>>>;
    getLastValueForSubscriptionRequest(subscriptionRequest: SubscriptionRequest): Promise<LastValueTelemetryResponse | LastValueConnectionStateResponse | LastValueDeviceTwinResponse | LastValueResponse<undefined>>;
    private log;
}
