import { GrantRequest, TwinUpdate } from './ux4iot-shared';
export declare type Subscribers = Record<string, string[]>;
export declare enum GRANT_RESPONSES {
    FORBIDDEN = "FORBIDDEN",
    UNAUTHORIZED = "UNAUTHORIZED",
    GRANTED = "GRANTED",
    ERROR = "ERROR"
}
export declare type GrantRequestFunctionType = (grant: GrantRequest) => Promise<GRANT_RESPONSES>;
export declare type ConnectionUpdateReason = 'socket_connect' | 'socket_connect_error' | 'socket_disconnect' | 'ux4iot_unreachable';
export declare type ConnectionUpdateFunction = (reason: ConnectionUpdateReason, description?: string) => void;
export declare type InitializationOptions = {
    onSocketConnectionUpdate?: ConnectionUpdateFunction;
} & (InitializeDevOptions | InitializeProdOptions);
export declare type InitializeDevOptions = {
    adminConnectionString: string;
};
export declare type InitializeProdOptions = {
    ux4iotURL: string;
    grantRequestFunction: GrantRequestFunctionType;
};
export declare function isDevOptions(options: Record<string, unknown>): options is InitializeDevOptions;
export declare function isProdOptions(options: Record<string, unknown>): options is InitializeProdOptions;
export declare type MessageCallbackBase<T> = (deviceId: string, data: T | undefined, timestamp: string) => void;
export declare type TelemetryCallback = MessageCallbackBase<Record<string, unknown>>;
export declare type DeviceTwinCallback = MessageCallbackBase<TwinUpdate>;
export declare type ConnectionStateCallback = MessageCallbackBase<boolean>;
export declare type D2CMessageCallback = MessageCallbackBase<Record<string, unknown>>;
export declare type MessageCallback = TelemetryCallback | DeviceTwinCallback | ConnectionStateCallback | D2CMessageCallback;
export declare type PatchDesiredPropertiesOptions = Record<string, unknown>;
export declare type GrantErrorCallback = (error: GRANT_RESPONSES) => void;
export declare type SubscriptionErrorCallback = (error: any) => void;
