export declare type TwinUpdate = {
    version: number;
    properties: {
        reported: {
            [key: string]: any;
        };
        desired: {
            [key: string]: any;
        };
    };
};
export declare type DeviceId = string;
declare type GrantRequestBase<T> = {
    deviceId: string;
    sessionId: string;
} & T;
export declare type TelemetryGrantRequest = GrantRequestBase<{
    type: 'telemetry';
    telemetryKey?: string | null;
}>;
export declare type DeviceTwinGrantRequest = GrantRequestBase<{
    type: 'deviceTwin';
}>;
export declare type ConnectionStateGrantRequest = GrantRequestBase<{
    type: 'connectionState';
}>;
export declare type DesiredPropertyGrantRequest = GrantRequestBase<{
    type: 'desiredProperties';
}>;
export declare type DirectMethodGrantRequest = GrantRequestBase<{
    type: 'directMethod';
    directMethodName: string | null;
}>;
export declare type D2CMessageGrantRequest = GrantRequestBase<{
    type: 'd2cMessages';
}>;
export declare type GrantRequest = TelemetryGrantRequest | DeviceTwinGrantRequest | ConnectionStateGrantRequest | DesiredPropertyGrantRequest | DirectMethodGrantRequest | D2CMessageGrantRequest;
declare type SubscriptionRequestBase<T> = {
    deviceId: string;
    sessionId: string;
} & T;
export declare type TelemetrySubscriptionRequest = SubscriptionRequestBase<{
    type: 'telemetry';
    telemetryKey: string | null;
}>;
export declare type DeviceTwinSubscriptionRequest = SubscriptionRequestBase<{
    type: 'deviceTwin';
}>;
export declare type ConnectionStateSubscriptionRequest = SubscriptionRequestBase<{
    type: 'connectionState';
}>;
export declare type D2CMessageSubscriptionRequest = SubscriptionRequestBase<{
    type: 'd2cMessages';
}>;
export declare type SubscriptionRequest = TelemetrySubscriptionRequest | DeviceTwinSubscriptionRequest | ConnectionStateSubscriptionRequest | D2CMessageSubscriptionRequest;
export declare type ConnectionState = {
    connected: boolean;
};
export declare type MessageBase<T> = {
    deviceId: DeviceId;
    timestamp: string;
} & T;
export declare type TelemetryMessage = MessageBase<{
    telemetry: Record<string, unknown>;
}>;
export declare type ConnectionStateMessage = MessageBase<{
    connectionState: boolean;
}>;
export declare type DeviceTwinMessage = MessageBase<{
    deviceTwin: TwinUpdate;
}>;
export declare type D2CMessage = MessageBase<{
    message: Record<string, unknown>;
}>;
export declare type Message = TelemetryMessage | ConnectionStateMessage | DeviceTwinMessage | D2CMessage;
export declare type IoTHubResponse = {
    status: number;
    payload: unknown;
};
export declare type LogLevel = 'error' | 'warn' | 'info' | 'verbose' | 'debug';
export declare type ParsedConnectionString = {
    Endpoint: string;
    SharedAccessKey: string;
};
export declare function parseConnectionString(connectionString: string): ParsedConnectionString;
export declare const isGrantRequest: (request: unknown) => request is GrantRequest;
export declare const isTelemetryGrantRequest: (request: unknown) => request is TelemetryGrantRequest;
export declare const isDeviceTwinGrantRequest: (request: unknown) => request is DeviceTwinGrantRequest;
export declare const isConnectionStateGrantRequest: (request: unknown) => request is ConnectionStateGrantRequest;
export declare const isDesiredPropertyGrantRequest: (request: unknown) => request is DesiredPropertyGrantRequest;
export declare const isDirectMethodGrantRequest: (request: unknown) => request is DirectMethodGrantRequest;
export declare const isD2CMessageGrantRequest: (request: unknown) => request is D2CMessageGrantRequest;
export declare type LastValueResponse<T> = {
    deviceId: string;
    data: T;
    timestamp: string;
};
export declare type CachedValueType = string | boolean | number | Record<string, unknown>;
export declare type LastValueObj<T extends CachedValueType> = {
    value: T;
    timestamp: string;
};
export declare type LastValueTelemetryResponse = LastValueResponse<Record<string, LastValueObj<CachedValueType>>>;
export declare type LastValueDeviceTwinResponse = LastValueResponse<TwinUpdate>;
export declare type LastValueConnectionStateResponse = LastValueResponse<boolean>;
export declare type LastValuesBodyConfig = {
    connectionState?: boolean;
    deviceTwin?: boolean;
    telemetry?: string[];
};
export declare type LastValuesRequestBody = Record<string, LastValuesBodyConfig>;
export {};
