"use strict";
// twins won't change in the forseeable future so instead of using the "Twin['properties] type"
Object.defineProperty(exports, "__esModule", { value: true });
exports.isD2CMessageGrantRequest = exports.isDirectMethodGrantRequest = exports.isDesiredPropertyGrantRequest = exports.isConnectionStateGrantRequest = exports.isDeviceTwinGrantRequest = exports.isTelemetryGrantRequest = exports.isGrantRequest = exports.parseConnectionString = void 0;
function parseConnectionString(connectionString) {
    var parsed = connectionString.split(';').reduce(function (acc, part) {
        var i = part.indexOf('=');
        if (i < 0)
            return acc;
        var key = part.substring(0, i);
        var value = part.substring(i + 1);
        acc[key] = value;
        return acc;
    }, {});
    if (!parsed.Endpoint || !parsed.SharedAccessKey) {
        throw new Error("Invalid Connection String: make sure \"Endpoint=...\" and \"SharedAccessKey=...\" is present in your connection string.");
    }
    return parsed;
}
exports.parseConnectionString = parseConnectionString;
// Typeguards
var isGrantRequest = function (request) {
    return (!!request &&
        typeof request.deviceId === 'string' &&
        typeof request.sessionId === 'string');
};
exports.isGrantRequest = isGrantRequest;
var isTelemetryGrantRequest = function (request) {
    return (!!request &&
        (0, exports.isGrantRequest)(request) &&
        request.type === 'telemetry' &&
        typeof request.telemetryKey === 'string');
};
exports.isTelemetryGrantRequest = isTelemetryGrantRequest;
var isDeviceTwinGrantRequest = function (request) {
    return (!!request &&
        (0, exports.isGrantRequest)(request) &&
        request.type === 'deviceTwin');
};
exports.isDeviceTwinGrantRequest = isDeviceTwinGrantRequest;
var isConnectionStateGrantRequest = function (request) {
    return (!!request &&
        (0, exports.isGrantRequest)(request) &&
        request.type === 'connectionState');
};
exports.isConnectionStateGrantRequest = isConnectionStateGrantRequest;
var isDesiredPropertyGrantRequest = function (request) {
    return (!!request &&
        (0, exports.isGrantRequest)(request) &&
        request.type === 'desiredProperties');
};
exports.isDesiredPropertyGrantRequest = isDesiredPropertyGrantRequest;
var isDirectMethodGrantRequest = function (request) {
    return (!!request &&
        (0, exports.isGrantRequest)(request) &&
        request.type === 'directMethod' &&
        typeof request.directMethodName === 'string');
};
exports.isDirectMethodGrantRequest = isDirectMethodGrantRequest;
var isD2CMessageGrantRequest = function (request) {
    return (!!request &&
        (0, exports.isGrantRequest)(request) &&
        request.type === 'd2cMessages');
};
exports.isD2CMessageGrantRequest = isD2CMessageGrantRequest;
