import { ConnectionStateCallback, D2CMessageCallback, DeviceTwinCallback, MessageCallback, TelemetryCallback } from './types';
import { ConnectionStateGrantRequest, ConnectionStateSubscriptionRequest, D2CMessageGrantRequest, D2CMessageSubscriptionRequest, DesiredPropertyGrantRequest, DeviceTwinGrantRequest, DeviceTwinSubscriptionRequest, DirectMethodGrantRequest, GrantRequest, SubscriptionRequest, TelemetryGrantRequest, TelemetrySubscriptionRequest } from './ux4iot-shared';
export declare type Subscription = TelemetrySubscription | DeviceTwinSubscription | D2CMessageSubscription | ConnectionStateSubscription;
export declare type TelemetrySubscription = Omit<TelemetrySubscriptionRequest, 'telemetryKey'> & {
    onData: TelemetryCallback;
    telemetryKeys: string[];
};
export declare type DeviceTwinSubscription = DeviceTwinSubscriptionRequest & {
    onData: DeviceTwinCallback;
};
export declare type D2CMessageSubscription = D2CMessageSubscriptionRequest & {
    onData: D2CMessageCallback;
};
export declare type ConnectionStateSubscription = ConnectionStateSubscriptionRequest & {
    onData: ConnectionStateCallback;
};
declare type Ux4iotState = {
    grants: Ux4iotGrants;
    subscriptions: Ux4iotSubscriptions;
};
declare type Ux4iotGrants = {
    deviceTwin: DeviceTwinGrantRequest[];
    connectionState: ConnectionStateGrantRequest[];
    d2cMessages: D2CMessageGrantRequest[];
    telemetry: TelemetryGrantRequest[];
    desiredProperties: DesiredPropertyGrantRequest[];
    directMethod: DirectMethodGrantRequest[];
};
declare type Ux4iotSubscriptions = Record<string, Subscription[]>;
export declare const state: Ux4iotState;
export declare function resetState(): void;
export declare function hasSubscription(subscriberId: string, subscriptionRequest: SubscriptionRequest): boolean;
export declare function hasGrant(grantRequest: GrantRequest): boolean;
export declare function getNumberOfSubscribers(subscriptionRequest: SubscriptionRequest): number;
export declare function hasGrantForSubscription(subscriptionRequest: SubscriptionRequest): boolean;
export declare function addSubscription(subscriberId: string, subscriptionRequest: SubscriptionRequest, onData: MessageCallback): void;
export declare function removeSubscription(subscriberId: string, subscriptionRequest: SubscriptionRequest): Subscription | undefined;
export declare function addGrant(grantRequest: GrantRequest): void;
export declare function removeGrant(grantRequest: GrantRequest): void;
export declare function cleanSubId(subscriptionId: string): void;
export {};
