"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.cleanSubId = exports.removeGrant = exports.addGrant = exports.removeSubscription = exports.addSubscription = exports.hasGrantForSubscription = exports.getNumberOfSubscribers = exports.hasGrant = exports.hasSubscription = exports.resetState = exports.state = void 0;
var utils_1 = require("./utils");
exports.state = {
    grants: {
        deviceTwin: [],
        connectionState: [],
        d2cMessages: [],
        telemetry: [],
        desiredProperties: [],
        directMethod: [],
    },
    subscriptions: {},
};
function resetState() {
    exports.state.grants = {
        deviceTwin: [],
        connectionState: [],
        d2cMessages: [],
        telemetry: [],
        desiredProperties: [],
        directMethod: [],
    };
    exports.state.subscriptions = {};
}
exports.resetState = resetState;
function hasSubscription(subscriberId, subscriptionRequest) {
    if (!exports.state.subscriptions[subscriberId])
        return false;
    for (var _i = 0, _a = exports.state.subscriptions[subscriberId]; _i < _a.length; _i++) {
        var sub = _a[_i];
        var type = subscriptionRequest.type, deviceId = subscriptionRequest.deviceId, sessionId = subscriptionRequest.sessionId;
        var sType = sub.type, sDeviceId = sub.deviceId, sSessionId = sub.sessionId;
        if (sSessionId === sessionId && sDeviceId === deviceId && sType === type) {
            switch (type) {
                case 'connectionState':
                case 'd2cMessages':
                case 'deviceTwin':
                    return true;
                case 'telemetry': {
                    var telemetryKeys = sub.telemetryKeys;
                    return telemetryKeys.includes(subscriptionRequest.telemetryKey);
                }
            }
        }
    }
    return false;
}
exports.hasSubscription = hasSubscription;
function hasGrant(grantRequest) {
    for (var _i = 0, _a = Object.values(exports.state.grants); _i < _a.length; _i++) {
        var grants = _a[_i];
        for (var _b = 0, grants_1 = grants; _b < grants_1.length; _b++) {
            var grant = grants_1[_b];
            if ((0, utils_1.grantRequestsEqual)(grantRequest, grant))
                return true;
        }
    }
    return false;
}
exports.hasGrant = hasGrant;
function getNumberOfSubscribers(subscriptionRequest) {
    var subscriptionCount = 0;
    for (var _i = 0, _a = Object.values(exports.state.subscriptions); _i < _a.length; _i++) {
        var subscriptions = _a[_i];
        for (var _b = 0, subscriptions_1 = subscriptions; _b < subscriptions_1.length; _b++) {
            var sub = subscriptions_1[_b];
            var type = subscriptionRequest.type, deviceId = subscriptionRequest.deviceId, sessionId = subscriptionRequest.sessionId;
            var sType = sub.type, sDeviceId = sub.deviceId, sSessionId = sub.sessionId;
            if (sessionId === sSessionId &&
                sDeviceId === deviceId &&
                sType === type) {
                switch (type) {
                    case 'connectionState':
                    case 'd2cMessages':
                    case 'deviceTwin':
                        subscriptionCount++;
                        break;
                    case 'telemetry': {
                        var telemetryKeys = sub.telemetryKeys;
                        if (telemetryKeys.includes(subscriptionRequest.telemetryKey)) {
                            subscriptionCount++;
                        }
                        break;
                    }
                }
            }
        }
    }
    return subscriptionCount;
}
exports.getNumberOfSubscribers = getNumberOfSubscribers;
function hasGrantForSubscription(subscriptionRequest) {
    var deviceId = subscriptionRequest.deviceId, type = subscriptionRequest.type, sessionId = subscriptionRequest.sessionId;
    for (var _i = 0, _a = Object.values(exports.state.grants); _i < _a.length; _i++) {
        var grants = _a[_i];
        for (var _b = 0, grants_2 = grants; _b < grants_2.length; _b++) {
            var grant = grants_2[_b];
            if (grant.deviceId !== deviceId || grant.sessionId !== sessionId) {
                continue;
            }
            switch (type) {
                case 'connectionState':
                case 'deviceTwin':
                case 'd2cMessages':
                    if (grant.type === type)
                        return true;
                    break;
                case 'telemetry': {
                    var telemetryKey = subscriptionRequest.telemetryKey;
                    if (grant.type === type && grant.telemetryKey === telemetryKey)
                        return true;
                    break;
                }
            }
        }
    }
    return false;
}
exports.hasGrantForSubscription = hasGrantForSubscription;
function addSubscription(subscriberId, subscriptionRequest, onData) {
    var subscriptions = exports.state.subscriptions;
    var type = subscriptionRequest.type, deviceId = subscriptionRequest.deviceId, sessionId = subscriptionRequest.sessionId;
    if (hasSubscription(subscriberId, subscriptionRequest)) {
        return;
    }
    switch (type) {
        case 'deviceTwin':
        case 'connectionState':
        case 'd2cMessages': {
            var subscription = { type: type, deviceId: deviceId, onData: onData, sessionId: sessionId };
            !subscriptions[subscriberId]
                ? (subscriptions[subscriberId] = [subscription])
                : subscriptions[subscriberId].push(subscription);
            break;
        }
        case 'telemetry': {
            var telemetryKey = subscriptionRequest.telemetryKey;
            var subscription = {
                type: type,
                deviceId: deviceId,
                onData: onData,
                telemetryKeys: [telemetryKey],
                sessionId: sessionId,
            };
            if (subscriptions[subscriberId]) {
                var foundSubscription = subscriptions[subscriberId].find(function (s) { return s.deviceId === deviceId; });
                if (foundSubscription) {
                    foundSubscription.telemetryKeys.push(telemetryKey);
                }
                else {
                    subscriptions[subscriberId].push(subscription);
                }
            }
            else {
                subscriptions[subscriberId] = [subscription];
            }
            break;
        }
        default:
            break;
    }
}
exports.addSubscription = addSubscription;
function removeSubscription(subscriberId, subscriptionRequest) {
    if (!exports.state.subscriptions[subscriberId]) {
        return;
    }
    var type = subscriptionRequest.type, deviceId = subscriptionRequest.deviceId, sessionId = subscriptionRequest.sessionId;
    switch (type) {
        case 'deviceTwin':
        case 'connectionState':
        case 'd2cMessages': {
            var subscriptionRequest_1 = exports.state.subscriptions[subscriberId].find(function (s) {
                return s.deviceId === deviceId &&
                    s.type === type &&
                    s.sessionId === sessionId;
            });
            exports.state.subscriptions[subscriberId] = exports.state.subscriptions[subscriberId].filter(function (s) { return s !== subscriptionRequest_1; });
            if (exports.state.subscriptions[subscriberId].length === 0) {
                delete exports.state.subscriptions[subscriberId];
            }
            return subscriptionRequest_1;
        }
        case 'telemetry':
            if (exports.state.subscriptions[subscriberId]) {
                var foundSubscription_1 = exports.state.subscriptions[subscriberId].find(function (s) {
                    return s.deviceId === deviceId && s.sessionId === sessionId;
                });
                if (foundSubscription_1) {
                    var keys = foundSubscription_1.telemetryKeys;
                    var telemetryKey_1 = subscriptionRequest.telemetryKey;
                    var nextTelemetryKeys = keys.filter(function (k) { return k !== telemetryKey_1; });
                    if (nextTelemetryKeys.length === 0) {
                        exports.state.subscriptions[subscriberId] = exports.state.subscriptions[subscriberId].filter(function (s) {
                            return s !== foundSubscription_1;
                        });
                    }
                    else {
                        foundSubscription_1.telemetryKeys = nextTelemetryKeys;
                    }
                }
                if (exports.state.subscriptions[subscriberId].length === 0) {
                    delete exports.state.subscriptions[subscriberId];
                }
                return foundSubscription_1;
            }
            break;
        default:
            break;
    }
}
exports.removeSubscription = removeSubscription;
function addGrant(grantRequest) {
    var grants = exports.state.grants;
    var type = grantRequest.type;
    //@ts-ignore type of grant request is correctly map in Ux4iotState
    grants[type].push(grantRequest);
}
exports.addGrant = addGrant;
function removeGrant(grantRequest) {
    var grants = exports.state.grants;
    var type = grantRequest.type;
    //@ts-ignore type of grant request is correctly map in Ux4iotState
    grants[type] = grants[type].filter(function (g) { return !(0, utils_1.grantRequestsEqual)(g, grantRequest); });
}
exports.removeGrant = removeGrant;
function cleanSubId(subscriptionId) {
    delete exports.state.subscriptions[subscriptionId];
}
exports.cleanSubId = cleanSubId;
